==> webkit_1.8.1.orig.tar.xz: webkit-1.8.1/Source/WebCore/html/LabelsNodeList.cpp <==
/**
 * Copyright (C) 1999 Lars Knoll (knoll@kde.org)
 *           (C) 1999 Antti Koivisto (koivisto@kde.org)
 *           (C) 2001 Dirk Mueller (mueller@kde.org)
 * Copyright (C) 2004, 2007, 2008 Apple Inc. All rights reserved.
 * Copyright (C) 2010 Nokia Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "config.h"
#include "LabelsNodeList.h"

#include "Element.h"
#include "HTMLLabelElement.h"
#include "HTMLNames.h"

namespace WebCore {

using namespace HTMLNames;

LabelsNodeList::LabelsNodeList(Node* forNode )
    : DynamicSubtreeNodeList(forNode->document()) , m_forNode(forNode)
{
}

LabelsNodeList::~LabelsNodeList()
{
    m_forNode->removeCachedLabelsNodeList(this);
} 
    
bool LabelsNodeList::nodeMatches(Element* testNode) const
{
    return testNode->hasTagName(labelTag) && static_cast<HTMLLabelElement*>(testNode)->control() == m_forNode;
}

} // namespace WebCore

==> webkit-1.9.1.tar.xz: webkit-1.9.1/Source/WebCore/html/LabelsNodeList.cpp <==
/**
 * Copyright (C) 1999 Lars Knoll (knoll@kde.org)
 *           (C) 1999 Antti Koivisto (koivisto@kde.org)
 *           (C) 2001 Dirk Mueller (mueller@kde.org)
 * Copyright (C) 2004, 2007, 2008 Apple Inc. All rights reserved.
 * Copyright (C) 2010 Nokia Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "config.h"
#include "LabelsNodeList.h"

#include "Element.h"
#include "HTMLLabelElement.h"
#include "HTMLNames.h"

namespace WebCore {

using namespace HTMLNames;

LabelsNodeList::LabelsNodeList(Node* forNode )
    : DynamicSubtreeNodeList(forNode->document()) , m_forNode(forNode)
{
    m_forNode->document()->registerDynamicSubtreeNodeList(this);
}

LabelsNodeList::~LabelsNodeList()
{
    m_forNode->removeCachedLabelsNodeList(this);
    m_forNode->document()->unregisterDynamicSubtreeNodeList(this);
} 
    
bool LabelsNodeList::nodeMatches(Element* testNode) const
{
    return testNode->hasTagName(labelTag) && static_cast<HTMLLabelElement*>(testNode)->control() == m_forNode;
}

} // namespace WebCore
